#include "stm32f10x.h"
#include "2021_i2c.h"
#include "oled_ascii.h"

u8 DataDeal(u8 data)//ֽڵ   core_cm3.h
{
  u32 res;
  res= data<<24;
  res= __RBIT(res);
  return (u8)res;
}

void i2c_gpio_init(void)
{
	GPIO_InitTypeDef GPIO_InitStructure;
	
	GPIO_InitStructure.GPIO_Pin = SDA_PIN;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_OD;       
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_Init(SDA_GPIO, &GPIO_InitStructure);
	
	GPIO_InitStructure.GPIO_Pin = SCL_PIN;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_OD;       
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_Init(SCL_GPIO, &GPIO_InitStructure);
	
	GPIO_InitStructure.GPIO_Pin = RST_PIN;
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;       
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
	GPIO_Init(RST_GPIO, &GPIO_InitStructure);
}


void i2c_delay_times(u32 times)
{
	//while(times--);
}



void i2c_free(void)
{
			SCL_H();
			SDA_H();
			i2c_delay_times(i2c_delay);
}

void i2c_start(void)
{
		SCL_H();
		SDA_H();
		i2c_delay_times(i2c_delay);
	
		SDA_L();
		i2c_delay_times(i2c_delay);
	
		SCL_L();
		i2c_delay_times(i2c_delay);
}

void i2c_stop(void)
{
		SCL_L();//must   when scl is low 
		i2c_delay_times(i2c_delay);
		SDA_L();
		i2c_delay_times(i2c_delay);
		SCL_H();
		i2c_delay_times(i2c_delay);
		SDA_H();
		i2c_delay_times(i2c_delay);

}

void i2c_write_data(u8 temp)
{
		u8 i;
		for(i=0;i<8;i++)
		{
			SCL_L();//when sck is low  ,data can change
			i2c_delay_times(i2c_delay);
			
			if((temp&0x80)==0x80)
			SDA_H();
			else
			SDA_L();	
			i2c_delay_times(i2c_delay);
			
			SCL_H();
			i2c_delay_times(i2c_delay);
		
			temp=temp<<1;
			
			SCL_L();
		}
		SDA_H();
}


u8 i2c_read_data(void)
{
		u8 i,temp;

		SDA_H();
		for(i=0;i<8;i++)
		{
			temp=temp<<1;
			
			SCL_L();
			i2c_delay_times(i2c_delay);
			SCL_H();
			i2c_delay_times(i2c_delay);
			if(SDA_STAT()==1)
			temp=temp|0x01;
			else
			;
			
			i2c_delay_times(i2c_delay);
			
			SCL_L();
			
		}
			
		return temp;
	
}
	
void i2c_ack(void)
{

		SCL_L();
		i2c_delay_times(i2c_delay);
	
		SDA_L();
		i2c_delay_times(i2c_delay);
	
		SCL_H();
		i2c_delay_times(i2c_delay);
		SCL_L();
		i2c_delay_times(i2c_delay);
	
}
	
void i2c_nack(void)
{
		SCL_L();
		i2c_delay_times(i2c_delay);
	
		SDA_H();
		i2c_delay_times(i2c_delay);
	
		SCL_H();
		i2c_delay_times(i2c_delay);
		SCL_L();
		i2c_delay_times(i2c_delay);
}

u8 i2c_waitack(void)
{
		u8 temp;
	
		SCL_L();

		i2c_delay_times(i2c_delay);
		SDA_H();
		i2c_delay_times(i2c_delay);
	
		SCL_H();
		i2c_delay_times(i2c_delay);
	
		if(SDA_STAT()==0)
			temp=0x01;//suss
		else
			temp=0x00;
	
		SCL_L();

	
	return temp;
}

u8 text_i2c_address(u8 address)
{			
			u8 pass;
			i2c_start();
			i2c_write_data(address);
			pass=i2c_waitack();//0x01 pass  0x00 NG
			i2c_stop();
			return pass;
}

//--------------EEPROM------------------------------
u8 read_eeprom(u8 address)  //a0 a1   
{
			u8 temp;
			i2c_start();
			i2c_write_data(0xa0);
			i2c_waitack();
			i2c_write_data(address);
			i2c_waitack();
	
			i2c_start();
			i2c_write_data(0xa1);
			i2c_waitack();
			temp=i2c_read_data();
			i2c_nack();
			i2c_stop();
	
			return temp;

}

void write_eeprom(u8 address,u8 temp)
{
			i2c_start();
			i2c_write_data(0xa0);
			i2c_waitack();
			i2c_write_data(address);
			i2c_waitack();
			i2c_write_data(temp);
			i2c_waitack();
			i2c_stop();

}

//---------------OLED-------------------------------
void write_oled_12864(u8 temp,u8 address)
{
			i2c_start();
			i2c_write_data(0x78);
			i2c_waitack();
			i2c_write_data(address);
			i2c_waitack();
			i2c_write_data(temp);
			i2c_waitack();
			i2c_stop();
}

void reset_oled_12864(void)
{
	RST_L();
	i2c_delay_times(50000);
	RST_H();
	i2c_delay_times(5000);
}

void init_oled_12864(void)
{

	i2c_delay_times(5000);
	
	write_oled_12864(0xe3,0x00);
	write_oled_12864(0xae,0x00);
	
	write_oled_12864(0xd5,0x00);
	write_oled_12864(0x80,0x00);
	
	write_oled_12864(0xa8,0x00);
	write_oled_12864(0x3f,0x00);
	
	write_oled_12864(0xd3,0x00);
	write_oled_12864(0x00,0x00);
	
	write_oled_12864(0x40,0x00);
	
	write_oled_12864(0x8d,0x00);
	write_oled_12864(0x14,0x00);
	
	write_oled_12864(0x14,0x00);
	write_oled_12864(0x20,0x00);
	
	write_oled_12864(0x02,0x00);	
	write_oled_12864(0xa0,0x00);
	
	write_oled_12864(0xc0,0x00);
	write_oled_12864(0xda,0x00);
	
	write_oled_12864(0x12,0x00);
	write_oled_12864(0x81,0x00);
	
	write_oled_12864(0x55,0x00);
	write_oled_12864(0xd9,0x00);
	
	write_oled_12864(0xf1,0x00);
	write_oled_12864(0xdb,0x00);
	
	write_oled_12864(0x40,0x00);
	write_oled_12864(0xa4,0x00);
	write_oled_12864(0xa6,0x00);
	write_oled_12864(0xad,0x00);
	write_oled_12864(0x30,0x00);
	

	
	write_oled_12864(0x00,0x00);	//õеַ
	write_oled_12864(0x10,0x00);	//øеַ
	write_oled_12864(0x40,0x00);	//ʼеַ
	write_oled_12864(0xB0,0x00);	//ҳַ
	write_oled_12864(0xA1,0x00);	//öΣSEGʼӳַcolumn127ַSEG0ĵַ
	
	write_oled_12864(0xA6,0x00);	//ʾ0xa7ʾ
	write_oled_12864(0xC8,0x00);	//ӳģʽCOM[N-1]~COM0ɨ
	

	
	write_oled_12864(0xaf,0x00);

	i2c_delay_times(5000);

}


void clear_oled_12864(u8 colour)
{
	u16 i,j;
	for(i=0;i<8;i++) 
	{
			write_oled_12864 (0xb0+i,0x00);    //0~7ҳд
			write_oled_12864 (0x00,0x00);      //е͵ַ
			write_oled_12864 (0x10,0x00);      //иߵַ  
			for(j=0;j<128;j++)
			{
				write_oled_12864(colour,0x40); //д 0 
			}
	}
}


void bmp_oled_12864(const u8 *table)
{
	u16 i,j;
	for(i=0;i<8;i++) 
	{
			write_oled_12864(0xb0+i,0x00);    //0~7ҳд
			write_oled_12864(0x00,0x00);      //е͵ַ
			write_oled_12864(0x10,0x00);      //иߵַ  
		
			i2c_start();
			i2c_write_data(0x78);
			i2c_waitack();
			i2c_write_data(0x40);
			i2c_waitack();
			for(j=0;j<128;j++)
			{		
				//	i2c_write_data(table[j+i*128]);
					i2c_write_data(DataDeal(table[j+i*128]));
					i2c_waitack();
			}

			i2c_stop();
	}
}

void front8_oled_12864(u8 x,u8 y,u8 data,u8 colour)
{
	u16 i;
	u8 x_lbyte,x_hbyte;
	
	x=x*8;
	x_lbyte=x;
	x_lbyte=x_lbyte<<4;
	x_lbyte=x_lbyte>>4;
	
	x_hbyte=x;
	x_hbyte=x_hbyte>>4;
	
	write_oled_12864 (0xb0+y,0x00);    
	write_oled_12864 (0x00+x_lbyte,0x00);      
	write_oled_12864 (0x10+x_hbyte,0x00);  
	if(colour==0)//
	{
		for(i=0;i<5;i++)
			write_oled_12864(font_5_8[data][i],0x40); 
		
			write_oled_12864(0x00,0x40); 
			write_oled_12864(0x00,0x40); 
			write_oled_12864(0x00,0x40); 
	}
	else
	{
			for(i=0;i<5;i++)
			write_oled_12864(~font_5_8[data][i],0x40); 
		
			write_oled_12864(0xFF,0x40); 
			write_oled_12864(0xFF,0x40); 
			write_oled_12864(0xFF,0x40); 
	}
}

void front16_oled_12864(u8 x,u8 y,u8 data,u8 colour)
{
	u16 i;
	u8 x_lbyte,x_hbyte;
	
	x=x*8;
	x_lbyte=x;
	x_lbyte=x_lbyte<<4;
	x_lbyte=x_lbyte>>4;
	
	x_hbyte=x;
	x_hbyte=x_hbyte>>4;
	
	y=y*2;
	
	write_oled_12864 (0xb0+y,0x00);    
	write_oled_12864 (0x00+x_lbyte,0x00);      
	write_oled_12864 (0x10+x_hbyte,0x00);      
	if(colour==0)//
	{
		for(i=0;i<8;i++)
			write_oled_12864(font_8_16[data][i],0x40); 
	}
	else 
	{
		for(i=0;i<8;i++)
			write_oled_12864(~font_8_16[data][i],0x40); 
	}
	
	write_oled_12864 (0xb0+y+1,0x00);    
	write_oled_12864 (0x00+x_lbyte,0x00);     
	write_oled_12864 (0x10+x_hbyte,0x00);     
	if(colour==0)//
	{
		for(i=0;i<8;i++)
			write_oled_12864(font_8_16[data][i+8],0x40); 
	}
	else
	{
		for(i=0;i<8;i++)
			write_oled_12864(~font_8_16[data][i+8],0x40); 
	}

}


void front16_16_oled_12864(u8 x,u8 y,u8 data,u8 colour)
{
	u16 i;
	u8 x_lbyte,x_hbyte;
	
	x=x*16;
	x_lbyte=x;
	x_lbyte=x_lbyte<<4;
	x_lbyte=x_lbyte>>4;
	
	x_hbyte=x;
	x_hbyte=x_hbyte>>4;
	
	y=y*2;
	
	write_oled_12864 (0xb0+y,0x00);   
	write_oled_12864 (0x00+x_lbyte,0x00);     
	write_oled_12864 (0x10+x_hbyte,0x00);      
	if(colour==0)
	{
		for(i=0;i<16;i++)
			write_oled_12864(font_16_16[data][i],0x40);
	}
	else
	{
		for(i=0;i<16;i++)
			write_oled_12864(~font_16_16[data][i],0x40);
	}


	write_oled_12864 (0xb0+y+1,0x00);   
	write_oled_12864 (0x00+x_lbyte,0x00);    
	write_oled_12864 (0x10+x_hbyte,0x00);    
	if(colour==0)
	{
		for(i=0;i<16;i++)
			write_oled_12864(font_16_16[data][i+16],0x40); 
	}
	else
	{
		for(i=0;i<16;i++)
			write_oled_12864(~font_16_16[data][i+16],0x40); 
	}

}

void front16_32_oled_12864(u8 x,u8 y,u8 data,u8 colour)//2021.8.2 Ż
{
	u16 i;
	u8 x_lbyte,x_hbyte;
	
	x=x*16;
	x_lbyte=x;
	x_lbyte=x_lbyte<<4;
	x_lbyte=x_lbyte>>4;
	
	x_hbyte=x;
	x_hbyte=x_hbyte>>4;
	
	y=y*2;
	
	write_oled_12864 (0xb0+y,0x00);    //0~7ҳд  8*8
	write_oled_12864 (0x00+x_lbyte,0x00);      //е͵ַ
	write_oled_12864 (0x10+x_hbyte,0x00);      //иߵַ  
	if(colour==0)
	{
		for(i=0;i<16;i++)
			write_oled_12864(font_16_32[data][i],0x40); //д һҳ(8Ϊһҳ)16(8bit)
	}
	else
	{
		for(i=0;i<16;i++)
			write_oled_12864(~font_16_32[data][i],0x40); //д һҳ(8Ϊһҳ)16(8bit)
	}


	write_oled_12864 (0xb0+y+1,0x00);   
	write_oled_12864 (0x00+x_lbyte,0x00);      
	write_oled_12864 (0x10+x_hbyte,0x00);    
	if(colour==0)
	{
		for(i=0;i<16;i++)
			write_oled_12864(font_16_32[data][i+16],0x40); 
	}
	else
	{
		for(i=0;i<16;i++)
			write_oled_12864(~font_16_32[data][i+16],0x40); 
	}	

		
	write_oled_12864 (0xb0+y+2,0x00);   
	write_oled_12864 (0x00+x_lbyte,0x00);      
	write_oled_12864 (0x10+x_hbyte,0x00);   
	if(colour==0)
	{
		for(i=0;i<16;i++)
			write_oled_12864(font_16_32[data][i+32],0x40); 
	}
	else
	{
		for(i=0;i<16;i++)
			write_oled_12864(~font_16_32[data][i+32],0x40); 
	}	


	write_oled_12864 (0xb0+y+3,0x00);    
	write_oled_12864 (0x00+x_lbyte,0x00);     
	write_oled_12864 (0x10+x_hbyte,0x00);    
	if(colour==0)
	{
		for(i=0;i<16;i++)
			write_oled_12864(font_16_32[data][i+48],0x40); 
	}
	else
	{
		for(i=0;i<16;i++)
			write_oled_12864(~font_16_32[data][i+48],0x40); 
	}	

		
}



u8 oled_buff[128][8];

void clear_oled_buff(void)
{
		u8 i,j;
	for(i=0;i<128;i++)
	{
			for(j=0;j<8;j++)
			{
				oled_buff[i][j]=0;
			}
	}
}

//buff㺯 2021.3.13
void write_point_oled(u8 x,u8 y)
{

	u8 temp_table[8]={0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x80};
	u8 temp;
	u8 old_data;
	u8 x_lbyte,x_hbyte;
	
	x_lbyte=x;
	x_lbyte=x_lbyte<<4;
	x_lbyte=x_lbyte>>4;
	
	x_hbyte=x;
	x_hbyte=x_hbyte>>4;
	

	old_data=oled_buff[x][y/8];//ȡ
	
	temp=temp_table[y%8];
	temp=temp|old_data;
	
	oled_buff[x][y/8]=temp;//д뻺
	
	y=y/8;
	
	write_oled_12864 (0xb0+y,0x00);    //0~7ҳд  
	write_oled_12864 (0x00+x_lbyte,0x00);      //е͵ַ
	write_oled_12864 (0x10+x_hbyte,0x00);      //иߵַ  

	write_oled_12864(temp,0x40); //д 
	
}
//buff㺯 2021.3.13
void clear_point_oled(u8 x,u8 y)
{

	u8 temp_table[8]={0x01,0x02,0x04,0x08,0x10,0x20,0x40,0x80};
	u8 temp;
	u8 old_data;
	u8 x_lbyte,x_hbyte;
	
	x_lbyte=x;
	x_lbyte=x_lbyte<<4;
	x_lbyte=x_lbyte>>4;
	
	x_hbyte=x;
	x_hbyte=x_hbyte>>4;
	

	old_data=oled_buff[x][y/8];//ȡ
	
	temp=temp_table[y%8];//ȡ
	
	temp=(0xff-temp)&old_data;
	
	oled_buff[x][y/8]=temp;//д뻺
	
	y=y/8;
	
	write_oled_12864 (0xb0+y,0x00);    //0~7ҳд  
	write_oled_12864 (0x00+x_lbyte,0x00);      //е͵ַ
	write_oled_12864 (0x10+x_hbyte,0x00);      //иߵַ  

	write_oled_12864(temp,0x40); //д 
}



//---------ina226 2021.3.13-------------------------

u16 read_ina226(u8 address)
{
			u16 temp;
			u8 temp_l,temp_h;
	
			i2c_start();
			i2c_write_data(0x80);
			i2c_waitack();
			i2c_write_data(address);
			i2c_waitack();
	
			i2c_start();
			i2c_write_data(0x81);
			i2c_waitack();
			temp_h=i2c_read_data();
			i2c_ack();
			temp_l=i2c_read_data();
			i2c_nack();
			i2c_stop();
	
			temp=temp_h;
			temp=temp<<8;
			temp=temp+temp_l;
	
			return temp;
	

}

void write_ina226(u8 address,u16 temp)
{
			u8 temp_l,temp_h;
			temp_l=temp;
			temp_h=temp>>8;
	
			i2c_start();
			i2c_write_data(0x80);
			i2c_waitack();
			i2c_write_data(address);
			i2c_waitack();
			i2c_write_data(temp_h);
			i2c_waitack();
			i2c_write_data(temp_l);
			i2c_waitack();
			i2c_stop();

}
void init_ina226(void)
{
		write_ina226(0x05,512);//CalibrationRegister
}

u8 read_back_init_ina226(void)//֤Ƿ 0 OK  1 error
{
		u16 temp;
		temp=read_ina226(0x05);
		if(temp==512)
		return 0;
		else
		return 1;
}

//CSC2313 OR TDA7313  i2c address 0x88  2021.6.12---
u8 csc2313_data_buff[8];

//һдĴ 
void write_csc2313_reg(void)
{
			i2c_start();
			i2c_write_data(0x88);
			i2c_waitack();
			i2c_write_data(csc2313_data_buff[0]);
			i2c_waitack();
			i2c_write_data(csc2313_data_buff[1]);
			i2c_waitack();
			i2c_write_data(csc2313_data_buff[2]);
			i2c_waitack();
			i2c_write_data(csc2313_data_buff[3]);
			i2c_waitack();
			i2c_write_data(csc2313_data_buff[4]);
			i2c_waitack();
			i2c_write_data(csc2313_data_buff[5]);
			i2c_waitack();
			i2c_write_data(csc2313_data_buff[6]);
			i2c_waitack();
			i2c_write_data(csc2313_data_buff[7]);
			i2c_waitack();
			i2c_stop();
}


// 
void csc2313_volume_control(u16 data_buff)
{		
		//0-100 ת  63-0
		if(data_buff>100) data_buff=100;
		data_buff=data_buff*10;
		data_buff=data_buff/16;
		data_buff=63-data_buff;
		//ϼĴַ 0x00
		csc2313_data_buff[0]=0x00+data_buff;
}

//˥      					  ǰţ  								 ţ
void csc2313_speaker_attenuators(u8 lf_data_buff,u8 rf_data_buff,u8 lr_data_buff,u8 rr_data_buff)
{
		u8 tog_lf,tog_rf,tog_lr,tog_rr;
		/*
		LF ǰ  80
		RF ǰ  A0
		LR   C0
		RR Һ  E0
	
		Ldb λ 0-7
		Hdb λ 0-3
	
		0-31
	
		*/
		if(lf_data_buff<=31)
		{
				tog_lf=lf_data_buff;
		}
		if(rf_data_buff<=31)
		{
				tog_rf=rf_data_buff;
		}
		if(lr_data_buff<=31)
		{
				tog_lr=lr_data_buff;
		}
		if(rr_data_buff<=31)
		{
				tog_rr=rr_data_buff;
		}
			
//  ϼĴַ 0x80 0xa0 0xc0 0xe0
		csc2313_data_buff[1]=tog_lr+0x80;
		csc2313_data_buff[2]=tog_rr+0xa0;
		csc2313_data_buff[3]=tog_lf+0xc0;
		csc2313_data_buff[4]=tog_rf+0xe0;
}
//Ƶ                   ѡ    ȿ   
void csc2313_audio_switch(u8 input_sw,u8 gain_sw,u8 gain_value)
{
		u8 tog_data;
		/*
		audio_switch  0x40
		
		ѡ  
		input_sw    0   1 
								1   2 
								2   3
								3   4 δ
		
		ȿ    
		gain_sw			0  ȿ 
								1  ȹ 
		
		
		gain_value  0   +11.25 dB 
								1   +7.5 dB 
								2   +3.75 dB 
								3   0 dB 	
		*/
		if(input_sw>3)   input_sw=3;
		if(gain_sw>1)    input_sw=1;
		if(gain_value>3) input_sw=3;
		
		gain_value=3-gain_value;
		gain_sw=1-gain_sw;
		
		tog_data=gain_value;
		tog_data=tog_data<<1;
		tog_data=tog_data+gain_sw;
		tog_data=tog_data<<2;
		tog_data=tog_data+input_sw;

		
//  ϼĴַ 0x40	
		csc2313_data_buff[5]=tog_data+0x40;
	
	
}

//͵ Bass and Treble
void csc2313_bass_and_treble(u8 bass_value,u8 treble_value)
{
		u8 tog_bass_data,tog_treble_data;
		/*
		  0x60
		  0x70									 BCD
								0 0 0 0 	 -14dB   0
								0 0 0 1 	 -12dB	 1
								0 0 1 0 	 -10dB 	 2
								0 0 1 1  	 -8 dB	 3
								0 1 0 0 	 -6	dB	 4
								0 1 0 1  	 -4	dB	 5
								0 1 1 0 	 -2 dB	 6
								0 1 1 1 	  0 dB	 7
		
								1 1 1 1 	  0 dB   15
								1 1 1 0  	 +2 dB   14
								1 1 0 1	 	 +4 dB   13
								1 1 0 0    +6 dB   12
								1 0 1 1    +8 dB   11
								1 0 1 0    +10dB   10
								1 0 0 1    +12dB   9
								1 0 0 0  	 +14dB   8

		*/
		//0-15 ת 0-7 15-8
		
		if(bass_value<=7)
		{
				tog_bass_data=bass_value;
		}
		else if(bass_value<=15)
		{
				tog_bass_data=15-(bass_value-8);
		}
		else
		{
				tog_bass_data=7;//0db
		}
		
		if(treble_value<=7)
		{
				tog_treble_data=treble_value;
		}
		else if(treble_value<=15)
		{
				tog_treble_data=15-(treble_value-8);
		}
		else
		{
				tog_treble_data=7;//0db
		}
		
		//ϼĴַ
		csc2313_data_buff[6]=0x60+tog_bass_data;
		csc2313_data_buff[7]=0x70+tog_treble_data;

}


//----------------------------------------------------------------------
//PCF8563  I2C-bus slave address: read A3h and write A2h
//2021.8.1
void write_pcf8563(u8 address,u8 temp)
{
			i2c_start();
			i2c_write_data(0xa2);
			i2c_waitack();
			i2c_write_data(address);
			i2c_waitack();
			i2c_write_data(temp);
			i2c_waitack();
			i2c_stop();
}

u8 read_pcf8563(u8 address)
{
			u8 temp;
			i2c_start();
			i2c_write_data(0xa2);
			i2c_waitack();
			i2c_write_data(address);
			i2c_waitack();
	
			i2c_start();
			i2c_write_data(0xa3);
			i2c_waitack();
			temp=i2c_read_data();
			i2c_nack();
			i2c_stop();
	
			return temp;
}

void read_pcf8563_time(u8 *data)
{
			i2c_start();
			i2c_write_data(0xa2);
			i2c_waitack();
			i2c_write_data(0x00);
			i2c_waitack();
	
			i2c_start();
			i2c_write_data(0xa3);
			i2c_waitack();
			data[0]=i2c_read_data();
			i2c_ack();
			data[1]=i2c_read_data();
			i2c_ack();
			data[2]=i2c_read_data();
			i2c_ack();
			data[3]=i2c_read_data();
			i2c_ack();
			data[4]=i2c_read_data();
			i2c_ack();
			data[5]=i2c_read_data();
			i2c_ack();
			data[6]=i2c_read_data();
			i2c_ack();
			data[7]=i2c_read_data();
			i2c_ack();
			data[8]=i2c_read_data();
			i2c_nack();
			i2c_stop();

}

void write_pcf8563_time(u8 *data)
{

			i2c_start();
			i2c_write_data(0xa2);
			i2c_waitack();
			i2c_write_data(0x00);
			i2c_waitack();
	
			i2c_write_data(data[0]);
			i2c_waitack();
			i2c_write_data(data[1]);
			i2c_waitack();
			i2c_write_data(data[2]);
			i2c_waitack();
			i2c_write_data(data[3]);
			i2c_waitack();
			i2c_write_data(data[4]);
			i2c_waitack();
			i2c_write_data(data[5]);
			i2c_waitack();
			i2c_write_data(data[6]);
			i2c_waitack();
			i2c_write_data(data[7]);
			i2c_waitack();
			i2c_write_data(data[8]);
			i2c_waitack();

			i2c_stop();
}









